textmining.tmDocumentFactory.EnjuRecordDocumentStream

|  | ## Cheshire3 Object Model: Class EnjuRecordDocumentStream

Package textmining :: Module tmDocumentFactory :: Class EnjuRecordDocumentStream

## Class EnjuRecordDocumentStream
source code

Object Tree:

    documentFactory.BaseDocumentStream --+
                                         |
                                        EnjuRecordDocumentStream

Instance Methods

open_stream(self, stream)
find_documents(self, session, cache=0)
Inherited from `documentFactory.BaseDocumentStream`: `__init__`, `fetch_document`

Class Variables

Inherited from `documentFactory.BaseDocumentStream`: `codec`, `documents`, `factory`, `filterRe`, `format`, `length`, `locations`, `schema`, `stream`, `streamLocation`

Method Details

### open_stream(self, stream) | source code
Overrides: documentFactory.BaseDocumentStream.open_stream

### find_documents(self, session, cache=0) | source code